@@ -1,8 +1,8 @@
 /*
- * $Id: EdbusMessage.cpp 2967 2009-12-02 14:31:34Z karijes $
+ * $Id: EdbusMessage.cpp 3451 2012-11-28 15:11:09Z karijes $
  *
  * D-BUS stuff
- * Copyright (c) 2008 edelib authors
+ * Copyright (c) 2008-2012 edelib authors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -468,6 +468,13 @@ static void from_dbus_iter_to_edbusdata_type(DBusMessageIter* iter, EdbusData& d
 		data = EdbusData::from_uint64(v);
 		return;
 	} 
+
+	if(dtype == DBUS_TYPE_DOUBLE) {
+		double v;
+		dbus_message_iter_get_basic(iter, &v);
+		data = EdbusData::from_double(v);
+		return;
+	}
 	
 	if(dtype == DBUS_TYPE_STRING) {
 		/* TODO: strings are UTF-8 encoded */
@@ -494,7 +501,7 @@ static void from_dbus_iter_to_edbusdata_type(DBusMessageIter* iter, EdbusData& d
 
 			/* check type of array entries */
 			if(dbus_message_iter_get_arg_type(&array_iter) == DBUS_TYPE_INVALID) {
-				E_WARNING(E_STRLOC ": invalid in dict array!?");
+				E_WARNING(E_STRLOC ": invalid type in dict array??\n");
 
 				/* if fails, construct empty dict */
 				EdbusDict empty;
@@ -583,14 +590,11 @@ static void from_dbus_iter_to_edbusdata_type(DBusMessageIter* iter, EdbusData& d
 		data = EdbusData::from_struct(s);
 		return;
 	}
-
-	E_ASSERT(0 && "Got some unknown type from D-Bus ???");
+	
+	E_FATAL(E_STRLOC ": Got some unknown type from DBus (%i)???\n", dtype);
 }
 
 
-EdbusMessage::EdbusMessage() : dm(NULL) {
-}
-
 EdbusMessage::EdbusMessage(DBusMessage* msg) : dm(NULL) {
 	from_dbus_message(msg);
 }
@@ -605,16 +609,15 @@ EdbusMessage::~EdbusMessage() {
 
 #define CREATE_OR_CLEAR(m)                      \
 do {                                            \
-	if(!m) {                                    \
-		m = new EdbusMessageImpl;               \
-		m->msg = NULL;                          \
-	} else {                                    \
-		/* destroy previously create message */ \
-		clear_all();                            \
-	}                                           \
+    if(!m) {                                    \
+        m = new EdbusMessageImpl;               \
+        m->msg = NULL;                          \
+    } else {                                    \
+        /* destroy previously create message */ \
+        clear_all();                            \
+    }                                           \
 } while(0)
 
-
 void EdbusMessage::from_dbus_message(DBusMessage* m) {
 	CREATE_OR_CLEAR(dm);
 
