@@ -1,8 +1,8 @@
 /*
- * $Id: Netwm.cpp 3297 2012-05-15 13:18:51Z karijes $
+ * $Id: Netwm.cpp 3533 2013-03-04 23:20:19Z karijes $
  *
- * Functions for easier communication with window manager
- * Copyright (c) 2009 edelib authors
+ * Functions for easier communication with window managers
+ * Copyright (c) 2009-2013 edelib authors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -34,13 +34,16 @@
 EDELIB_NS_BEGIN
 
 struct NetwmCallbackData {
-	NetwmCallback  cb;
-	void		   *data;
+	NetwmCallback cb;
+	void		  *data;
 };
 
 typedef list<NetwmCallbackData> CbList;
 typedef list<NetwmCallbackData>::iterator CbListIt;
 
+typedef list<NetwmStateValue> NetwmStateList;
+typedef list<NetwmStateValue>::iterator NetwmStateListIt;
+
 static CbList callback_list;
 static int    input_selected = 0;
 
@@ -63,6 +66,7 @@ static Atom _XA_NET_WM_WINDOW_TYPE_COMBO;
 static Atom _XA_NET_WM_WINDOW_TYPE_DND;
 
 static Atom _XA_NET_WM_STRUT;
+static Atom _XA_NET_WM_STRUT_PARTIAL;
 static Atom _XA_NET_NUMBER_OF_DESKTOPS;
 static Atom _XA_NET_CURRENT_DESKTOP;
 static Atom _XA_NET_DESKTOP_NAMES;
@@ -105,8 +109,7 @@ static short atoms_inited = 0;
 static short xevent_added = 0;
 
 static void init_atoms_once(void) {
-	if(atoms_inited)
-		return;
+	if(atoms_inited) return;
 
 	REGISTER_ATOM(_XA_NET_WORKAREA,                     "_NET_WORKAREA");
 
@@ -128,6 +131,7 @@ static void init_atoms_once(void) {
 	REGISTER_ATOM(_XA_NET_WM_WINDOW_TYPE_DND,           "_NET_WM_WINDOW_TYPE_DND");
 
 	REGISTER_ATOM(_XA_NET_WM_STRUT,                     "_NET_WM_STRUT");
+	REGISTER_ATOM(_XA_NET_WM_STRUT_PARTIAL,             "_NET_WM_STRUT_PARTIAL");
 	REGISTER_ATOM(_XA_NET_NUMBER_OF_DESKTOPS,           "_NET_NUMBER_OF_DESKTOPS");
 	REGISTER_ATOM(_XA_NET_CURRENT_DESKTOP,              "_NET_CURRENT_DESKTOP");
 	REGISTER_ATOM(_XA_NET_DESKTOP_NAMES,                "_NET_DESKTOP_NAMES");
@@ -197,8 +201,8 @@ static int xevent_handler(int e) {
 			Window xid = fl_xevent->xproperty.window;
 
 			/* TODO: locking here */
-			CbListIt it = callback_list.begin(), it_end = callback_list.end();
-			for(; it != it_end; ++it) {
+			CbListIt it = callback_list.begin(), ite = callback_list.end();
+			for(; it != ite; ++it) {
 				/* execute callback */
 				(*it).cb(action, xid, (*it).data);
 			}
@@ -236,8 +240,8 @@ void netwm_callback_remove(NetwmCallback cb) {
 	if(callback_list.empty())
 		return;
 
-	CbListIt it = callback_list.begin(), it_end = callback_list.end();
-	while(it != it_end) {
+	CbListIt it = callback_list.begin(), ite = callback_list.end();
+	while(it != ite) {
 		if(cb == (*it).cb) {
 			it = callback_list.erase(it);
 		} else {
@@ -286,8 +290,8 @@ int netwm_workspace_get_count(void) {
 	unsigned char* prop;
 
 	int status = XGetWindowProperty(fl_display, RootWindow(fl_display, fl_screen), 
-			_XA_NET_NUMBER_OF_DESKTOPS, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_NUMBER_OF_DESKTOPS, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
 		return -1;
@@ -314,7 +318,7 @@ void netwm_workspace_change(int n) {
 	xev.xclient.data.l[0] = (long)n;
 	xev.xclient.data.l[1] = CurrentTime;
 
-	XSendEvent (fl_display, root_win, False, SubstructureRedirectMask | SubstructureNotifyMask, &xev);
+	XSendEvent(fl_display, root_win, False, SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 	XSync(fl_display, True);
 }
 
@@ -327,8 +331,8 @@ int netwm_workspace_get_current(void) {
 	unsigned char* prop;
 
 	int status = XGetWindowProperty(fl_display, RootWindow(fl_display, fl_screen), 
-			_XA_NET_CURRENT_DESKTOP, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_CURRENT_DESKTOP, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
 		return -1;
@@ -415,7 +419,7 @@ void netwm_window_set_type(Window win, int t) {
 	}
 
 	XChangeProperty(fl_display, win, _XA_NET_WM_WINDOW_TYPE, XA_ATOM, 32, PropModeReplace, 
-			(unsigned char*)&type, sizeof(Atom));
+					(unsigned char*)&type, 1);
 }
 
 int netwm_window_get_type(Window win) {
@@ -427,8 +431,8 @@ int netwm_window_get_type(Window win) {
 	unsigned char* prop = 0;
 
 	int status = XGetWindowProperty(fl_display, win, 
-			_XA_NET_WM_WINDOW_TYPE, 0L, sizeof(Atom), False, XA_ATOM, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_WM_WINDOW_TYPE, 0L, sizeof(Atom), False, XA_ATOM, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
 		return -1;
@@ -443,7 +447,6 @@ int netwm_window_get_type(Window win) {
 	else if(type == _XA_NET_WM_WINDOW_TYPE_UTILITY)       return NETWM_WINDOW_TYPE_UTILITY;
 	else if(type == _XA_NET_WM_WINDOW_TYPE_SPLASH)        return NETWM_WINDOW_TYPE_SPLASH;
 	else if(type == _XA_NET_WM_WINDOW_TYPE_DIALOG)        return NETWM_WINDOW_TYPE_DIALOG;
-
 	else if(type == _XA_NET_WM_WINDOW_TYPE_DROPDOWN_MENU) return NETWM_WINDOW_TYPE_DROPDOWN_MENU;
 	else if(type == _XA_NET_WM_WINDOW_TYPE_POPUP_MENU)    return NETWM_WINDOW_TYPE_POPUP_MENU;
 	else if(type == _XA_NET_WM_WINDOW_TYPE_TOOLTIP)       return NETWM_WINDOW_TYPE_TOOLTIP;
@@ -457,12 +460,20 @@ int netwm_window_get_type(Window win) {
 
 void netwm_window_set_strut(Window win, int left, int right, int top, int bottom) {
 	init_atoms_once();
-
 	/* TODO: should be longs */
-	long strut[4] = { left, right, top, bottom };
+	long strut[4] = {left, right, top, bottom};
 
 	XChangeProperty(fl_display, win, _XA_NET_WM_STRUT, XA_CARDINAL, 32, 
-			PropModeReplace, (unsigned char*)&strut, sizeof(long) * 4);
+					PropModeReplace, (unsigned char*)&strut, 4);
+}
+
+void netwm_window_set_strut_partial(Window win, int sizes[12]) {
+	init_atoms_once();
+	/* TODO: should be longs */
+	long *strutp = (long*)sizes;
+
+	XChangeProperty(fl_display, win, _XA_NET_WM_STRUT_PARTIAL, XA_CARDINAL, 32,
+					PropModeReplace, (unsigned char*)&strutp, 12);
 }
 
 void netwm_window_remove_strut(Window win) {
@@ -470,6 +481,11 @@ void netwm_window_remove_strut(Window win) {
 	XDeleteProperty(fl_display, win, _XA_NET_WM_STRUT);
 }
 
+void netwm_window_remove_strut_partial(Window win) {
+	init_atoms_once();
+	XDeleteProperty(fl_display, win, _XA_NET_WM_STRUT_PARTIAL);
+}
+
 int netwm_window_get_all_mapped(Window **windows) {
 	init_atoms_once();
 
@@ -479,8 +495,8 @@ int netwm_window_get_all_mapped(Window **windows) {
 	unsigned char* prop = 0;
 
 	int status = XGetWindowProperty(fl_display, RootWindow(fl_display, fl_screen), 
-			_XA_NET_CLIENT_LIST, 0L, 0x7fffffff, False, XA_WINDOW, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_CLIENT_LIST, 0L, 0x7fffffff, False, XA_WINDOW, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
 		return -1;
@@ -500,8 +516,8 @@ int netwm_window_get_workspace(Window win) {
 	unsigned char* prop = 0;
 
 	int status = XGetWindowProperty(fl_display, win, 
-			_XA_NET_WM_DESKTOP, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_WM_DESKTOP, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
 		return -1;
@@ -546,8 +562,8 @@ char *netwm_window_get_title(Window win) {
 	unsigned char* prop = 0;
 
 	int status = XGetWindowProperty(fl_display, win, 
-			_XA_NET_WM_NAME, 0L, 0x7fffffff, False, _XA_UTF8_STRING , &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_WM_NAME, 0L, 0x7fffffff, False, _XA_UTF8_STRING , &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status == Success && prop) {
 		title = (char *)prop;
@@ -583,7 +599,41 @@ char *netwm_window_get_title(Window win) {
 	return ret;
 }
 
-Fl_RGB_Image *netwm_window_get_icon(Window win) {
+/*
+ * Search for best icon in icon array and return offset in array; if not found matching size, use the first one.
+ * Image data is stored in form: [wh...w x h.....wh...w x h.....]
+ */
+static long *find_best_icon(long *data, int n, unsigned int req_w, unsigned int *rw, unsigned int *rh) {
+	E_RETURN_VAL_IF_FAIL(n > 3, NULL);
+
+	/* default values; we are sure we have at least 3 elements */
+	*rw = (unsigned int)data[0];
+	*rh = (unsigned int)data[1];
+	long *ret = (data + 2);
+
+	/* if we are not interested in searching offset */
+	if(req_w == 0) return ret;
+
+	unsigned int W, H;
+
+	for(int i = 0; i + 2 < n;) {
+		W = data[i++];
+		H = data[i++];
+
+		if(W == req_w) {
+			*rw = W;
+			*rh = H;
+			return (data + i);
+		}
+
+		i += W * H;
+	}
+
+	/* nothing found */
+	return ret;
+}
+
+Fl_RGB_Image *netwm_window_get_icon(Window win, unsigned int requested_width) {
 	E_RETURN_VAL_IF_FAIL(win >= 0, 0);
 	init_atoms_once();
 
@@ -591,46 +641,31 @@ Fl_RGB_Image *netwm_window_get_icon(Window win) {
 	int  format;
 	unsigned long n, extra;
 	unsigned char *prop = 0;
-	long len = 2;
 
 	int status = XGetWindowProperty(fl_display, win,
-			_XA_NET_WM_ICON, 0L, len, False, XA_CARDINAL, &real, &format, &n, &extra, (unsigned char**)&prop);
+									_XA_NET_WM_ICON, 0L, 0x7fffffff, False, XA_CARDINAL, &real, &format, &n, &extra, (unsigned char**)&prop);
 
-	if((status != Success) || (real != XA_CARDINAL)) {
-		E_WARNING(E_STRLOC ": Failed to get icon dimensions (status: %i is_cardinal: %i)\n", (status == Success), (real == XA_CARDINAL));
+	if((status != Success) || (real != XA_CARDINAL) || (n <= 2)) {
 		if(prop) XFree(prop);
 		return 0;
 	}
 
-	long *data = (long*)prop;
 	unsigned int width, height;
 
-	width  = data[0];
-	height = data[1];
-	XFree(prop);
-
-	len += width * height;
-
-	format = 0;
-	prop   = 0;
-	real   = 0;
-
-	status = XGetWindowProperty(fl_display, win,
-			_XA_NET_WM_ICON, 0L, len, False, XA_CARDINAL, &real, &format, &n, &extra, (unsigned char**)&prop);
-
-	if((status != Success) || (real != XA_CARDINAL)) {
-		E_WARNING(E_STRLOC ": Failed to get icon data (status: %i is_cardinal: %i)\n", (status == Success), (real == XA_CARDINAL));
+	long *data = find_best_icon((long*)prop, n, requested_width, &width, &height);
+	/* assure nothing have failed */
+	if(data == NULL) {
 		if(prop) XFree(prop);
 		return 0;
 	}
 
-	data = (long*)prop;
+	long len = width * height;
+	unsigned char *img_data, *ptr;
+	int pixel;
 
-	unsigned char *img_data = new unsigned char[width * height * 4];
-	unsigned char *ptr = img_data;
-	int            pixel;
+	ptr = img_data = new unsigned char[width * height * 4];
 
-	for(int i = 2; i < len; i++) {
+	for(int i = 0; i < len; i++) {
 		pixel = data[i];
 
 		*ptr++ = pixel >> 16 & 0xff;
@@ -643,7 +678,6 @@ Fl_RGB_Image *netwm_window_get_icon(Window win) {
 
 	Fl_RGB_Image *img = new Fl_RGB_Image(img_data, width, height, 4);
 	img->alloc_array = 1;
-
 	return img;
 }
 
@@ -656,11 +690,11 @@ Window netwm_window_get_active(void) {
 	unsigned char* prop = 0;
 
 	int status = XGetWindowProperty(fl_display, RootWindow(fl_display, fl_screen), 
-			_XA_NET_ACTIVE_WINDOW, 0L, sizeof(Atom), False, XA_WINDOW, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_NET_ACTIVE_WINDOW, 0L, sizeof(Atom), False, XA_WINDOW, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
-		return -1;
+		return (Window)-1; /* Window is int type */
 
 	int ret = int(*(long*)prop);
 	XFree(prop);
@@ -668,7 +702,7 @@ Window netwm_window_get_active(void) {
 	return (Window)ret;
 }
 
-void netwm_window_set_active(Window win) {
+void netwm_window_set_active(Window win, int source) {
 	init_atoms_once();	
 
 	XEvent xev;
@@ -680,12 +714,12 @@ void netwm_window_set_active(Window win) {
 	xev.xclient.display = fl_display;
 	xev.xclient.message_type = _XA_NET_ACTIVE_WINDOW;
 	xev.xclient.format = 32;
-	xev.xclient.data.l[0] = (long)win;
+	xev.xclient.data.l[0] = (long)source;
 	xev.xclient.data.l[1] = CurrentTime;
 	xev.xclient.data.l[2] = 0;
 
 	XSendEvent(fl_display, RootWindow(fl_display, fl_screen), False, 
-			SubstructureRedirectMask | SubstructureNotifyMask, &xev);
+			   SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 	XSync(fl_display, True);
 }
 
@@ -705,8 +739,8 @@ void netwm_window_maximize(Window win) {
 	xev.xclient.data.l[1] = _XA_NET_WM_STATE_MAXIMIZED_HORZ;
 	xev.xclient.data.l[2] = _XA_NET_WM_STATE_MAXIMIZED_VERT;
 
-	XSendEvent (fl_display, RootWindow(fl_display, fl_screen), False, 
-			SubstructureRedirectMask | SubstructureNotifyMask, &xev);
+	XSendEvent(fl_display, RootWindow(fl_display, fl_screen), False, 
+			   SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 	XSync(fl_display, True);
 }
 
@@ -725,8 +759,8 @@ void netwm_window_close(Window win) {
 	xev.xclient.data.l[0] = (long)win;
 	xev.xclient.data.l[1] = CurrentTime;
 
-	XSendEvent (fl_display, RootWindow(fl_display, fl_screen), False, 
-			SubstructureRedirectMask | SubstructureNotifyMask, &xev);
+	XSendEvent(fl_display, RootWindow(fl_display, fl_screen), False, 
+			   SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 	XSync(fl_display, True);
 }
 
@@ -745,8 +779,8 @@ void wm_window_ede_restore(Window win) {
 	xev.xclient.data.l[0] = _XA_EDE_WM_RESTORE_SIZE;
 	xev.xclient.data.l[1] = CurrentTime;
 
-	XSendEvent (fl_display, RootWindow(fl_display, fl_screen), False, 
-			SubstructureRedirectMask | SubstructureNotifyMask, &xev);
+	XSendEvent(fl_display, RootWindow(fl_display, fl_screen), False, 
+			   SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 	XSync(fl_display, True);
 }
 
@@ -771,41 +805,18 @@ void netwm_window_set_state(Window win, NetwmStateValue val, NetwmStateAction ac
 		Atom av;
 
 		switch(val) {
-			case NETWM_STATE_MODAL:
-				av = _XA_NET_WM_STATE_MODAL;
-				break;
-			case NETWM_STATE_STICKY:
-				av = _XA_NET_WM_STATE_STICKY;
-				break;
-			case NETWM_STATE_MAXIMIZED_VERT:
-				av = _XA_NET_WM_STATE_MAXIMIZED_VERT;
-				break;
-			case NETWM_STATE_MAXIMIZED_HORZ:
-				av = _XA_NET_WM_STATE_MAXIMIZED_HORZ;
-				break;
-			case NETWM_STATE_SHADED:
-				av = _XA_NET_WM_STATE_SHADED;
-				break;
-			case NETWM_STATE_SKIP_TASKBAR:
-				av = _XA_NET_WM_STATE_SKIP_TASKBAR;
-				break;
-			case NETWM_STATE_SKIP_PAGER:
-				av = _XA_NET_WM_STATE_SKIP_PAGER;
-				break;
-			case NETWM_STATE_HIDDEN:
-				av = _XA_NET_WM_STATE_HIDDEN;
-				break;
-			case NETWM_STATE_FULLSCREEN:
-				av = _XA_NET_WM_STATE_FULLSCREEN;
-				break;
-			case NETWM_STATE_ABOVE:
-				av = _XA_NET_WM_STATE_ABOVE;
-				break;
-			case NETWM_STATE_BELOW:
-				av = _XA_NET_WM_STATE_BELOW;
-				break;
-			case NETWM_STATE_DEMANDS_ATTENTION:
-				av = _XA_NET_WM_STATE_DEMANDS_ATTENTION;
+			case NETWM_STATE_MODAL:             av = _XA_NET_WM_STATE_MODAL; break;
+			case NETWM_STATE_STICKY:            av = _XA_NET_WM_STATE_STICKY; break;
+			case NETWM_STATE_MAXIMIZED_VERT:    av = _XA_NET_WM_STATE_MAXIMIZED_VERT; break;
+			case NETWM_STATE_MAXIMIZED_HORZ:    av = _XA_NET_WM_STATE_MAXIMIZED_HORZ; break;
+			case NETWM_STATE_SHADED:            av = _XA_NET_WM_STATE_SHADED; break;
+			case NETWM_STATE_SKIP_TASKBAR:      av = _XA_NET_WM_STATE_SKIP_TASKBAR; break;
+			case NETWM_STATE_SKIP_PAGER:        av = _XA_NET_WM_STATE_SKIP_PAGER; break;
+			case NETWM_STATE_HIDDEN:            av = _XA_NET_WM_STATE_HIDDEN; break;
+			case NETWM_STATE_FULLSCREEN:        av = _XA_NET_WM_STATE_FULLSCREEN; break;
+			case NETWM_STATE_ABOVE:             av = _XA_NET_WM_STATE_ABOVE; break;
+			case NETWM_STATE_BELOW:             av = _XA_NET_WM_STATE_BELOW; break;
+			case NETWM_STATE_DEMANDS_ATTENTION: av = _XA_NET_WM_STATE_DEMANDS_ATTENTION; break;
 			default:
 				E_WARNING(E_STRLOC ": Bad Netwm state: %i\n", action);
 				return;
@@ -815,11 +826,64 @@ void netwm_window_set_state(Window win, NetwmStateValue val, NetwmStateAction ac
 		xev.xclient.data.l[2] = 0;
 	}
 
-	XSendEvent (fl_display, RootWindow(fl_display, fl_screen), False, 
-			SubstructureRedirectMask | SubstructureNotifyMask, &xev);
+	XSendEvent(fl_display, RootWindow(fl_display, fl_screen), False, SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 	XSync(fl_display, True);
 }
 
+bool netwm_window_get_all_states(Window win, list<NetwmStateValue> &ret) {
+	init_atoms_once();	
+
+	Atom real;
+	int format;
+	unsigned long n, extra;
+	unsigned char* prop = 0;
+
+	int status = XGetWindowProperty(fl_display, win,
+									_XA_NET_WM_STATE, 0L, sizeof(Atom), False, _XA_WM_STATE, &real, &format, &n, &extra,
+									(unsigned char**)&prop);
+
+	if(status != Success || !prop)
+		return false;
+
+	Atom val, *data = (Atom*)prop;
+	NetwmStateValue st;
+
+	for(unsigned long i = 0; i < n; i++) {
+		val = data[i];
+		if(val ==_XA_NET_WM_STATE_MODAL)                   st = NETWM_STATE_MODAL;
+		else if(val == _XA_NET_WM_STATE_STICKY)            st = NETWM_STATE_STICKY;
+		else if(val == _XA_NET_WM_STATE_MAXIMIZED_VERT)    st = NETWM_STATE_MAXIMIZED_VERT;
+		else if(val == _XA_NET_WM_STATE_MAXIMIZED_HORZ)    st = NETWM_STATE_MAXIMIZED_HORZ;
+		else if(val == _XA_NET_WM_STATE_SHADED)            st = NETWM_STATE_SHADED;
+		else if(val == _XA_NET_WM_STATE_SKIP_TASKBAR)      st = NETWM_STATE_SKIP_TASKBAR;
+		else if(val == _XA_NET_WM_STATE_SKIP_PAGER)        st = NETWM_STATE_SKIP_PAGER;
+		else if(val == _XA_NET_WM_STATE_HIDDEN)            st = NETWM_STATE_HIDDEN;
+		else if(val == _XA_NET_WM_STATE_FULLSCREEN)        st = NETWM_STATE_FULLSCREEN;
+		else if(val == _XA_NET_WM_STATE_ABOVE)             st = NETWM_STATE_ABOVE;
+		else if(val == _XA_NET_WM_STATE_BELOW)             st = NETWM_STATE_BELOW;
+		else if(val == _XA_NET_WM_STATE_DEMANDS_ATTENTION) st = NETWM_STATE_DEMANDS_ATTENTION;
+		else continue;
+
+		ret.push_back(st);
+	}
+
+	XFree(prop);
+	return ret.size() > 0;
+}
+
+bool netwm_window_have_state(Window win, NetwmStateValue val) {
+	NetwmStateList lst;
+	E_RETURN_VAL_IF_FAIL(netwm_window_get_all_states(win, lst), false);
+
+	NetwmStateListIt it = lst.begin(), ite = lst.end();
+	for(; it != ite; ++it) {
+		if(*it == val)
+			return true;
+	}
+
+	return false;
+}
+
 WmStateValue wm_window_get_state(Window win) {
 	init_atoms_once();
 
@@ -829,8 +893,8 @@ WmStateValue wm_window_get_state(Window win) {
 	unsigned char* prop = 0;
 
 	int status = XGetWindowProperty(fl_display, win,
-			_XA_WM_STATE, 0L, sizeof(Atom), False, _XA_WM_STATE, &real, &format, &n, &extra, 
-			(unsigned char**)&prop);
+									_XA_WM_STATE, 0L, sizeof(Atom), False, _XA_WM_STATE, &real, &format, &n, &extra, 
+									(unsigned char**)&prop);
 
 	if(status != Success || !prop)
 		return WM_WINDOW_STATE_NONE;
